You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@xerces.apache.org by am...@apache.org on 2005/12/08 16:58:09 UTC

svn commit: r355132 - in /xerces/c/trunk: Projects/Win32/VC6/xerces-all/XercesLib/ Projects/Win32/VC7.1/xerces-all/XercesLib/ Projects/Win32/VC8/xerces-all/XercesLib/ src/ src/xercesc/dom/ src/xercesc/parsers/

Author: amassari
Date: Thu Dec  8 07:57:46 2005
New Revision: 355132

URL: http://svn.apache.org/viewcvs?rev=355132&view=rev
Log:
Rename DOMEntityResolver into DOMLSResourceResolver

Added:
    xerces/c/trunk/src/xercesc/dom/DOMLSResourceResolver.hpp
      - copied, changed from r354154, xerces/c/trunk/src/xercesc/dom/DOMEntityResolver.hpp
Removed:
    xerces/c/trunk/src/xercesc/dom/DOMEntityResolver.hpp
Modified:
    xerces/c/trunk/Projects/Win32/VC6/xerces-all/XercesLib/XercesLib.dsp
    xerces/c/trunk/Projects/Win32/VC7.1/xerces-all/XercesLib/XercesLib.vcproj
    xerces/c/trunk/Projects/Win32/VC8/xerces-all/XercesLib/XercesLib.vcproj
    xerces/c/trunk/src/Makefile.am
    xerces/c/trunk/src/Makefile.in
    xerces/c/trunk/src/xercesc/dom/DOM.hpp
    xerces/c/trunk/src/xercesc/dom/DOMLSInput.hpp
    xerces/c/trunk/src/xercesc/dom/DOMLSOutput.hpp
    xerces/c/trunk/src/xercesc/dom/DOMLSParser.hpp
    xerces/c/trunk/src/xercesc/parsers/DOMLSParserImpl.cpp
    xerces/c/trunk/src/xercesc/parsers/DOMLSParserImpl.hpp
    xerces/c/trunk/src/xercesc/parsers/XercesDOMParser.hpp

Modified: xerces/c/trunk/Projects/Win32/VC6/xerces-all/XercesLib/XercesLib.dsp
URL: http://svn.apache.org/viewcvs/xerces/c/trunk/Projects/Win32/VC6/xerces-all/XercesLib/XercesLib.dsp?rev=355132&r1=355131&r2=355132&view=diff
==============================================================================
--- xerces/c/trunk/Projects/Win32/VC6/xerces-all/XercesLib/XercesLib.dsp (original)
+++ xerces/c/trunk/Projects/Win32/VC6/xerces-all/XercesLib/XercesLib.dsp Thu Dec  8 07:57:46 2005
@@ -45,7 +45,7 @@
 # PROP Ignore_Export_Lib 0
 # PROP Target_Dir ""
 # ADD BASE CPP /MT /W3 /GX /O2 /D "WIN32" /D "NDEBUG" /D "_WINDOWS" /YX /FD /c
-# ADD CPP /nologo /GB /MD /W3 /GX /O2 /Ob2 /I "..\..\..\..\..\src" /D "NDEBUG" /D "PLATFORM_WIN32" /D "_CRTDBG_MAP_ALLOC" /D "XERCES_USE_FILEMGR_WINDOWS" /D "XERCES_USE_MUTEXMGR_WINDOWS" /D "XERCES_USE_ATOMICOPMGR_WINDOWS" /D "XERCES_USE_NETACCESSOR_WINSOCK" /D "XERCES_USE_WIN32_MSGLOADER" /D "XERCES_USE_TRANSCODER_WINDOWS" /D "XERCES_PATH_DELIMITER_BACKSLASH" /D "XERCES_BUILDING_LIBRARY" /D "WIN32" /D "_WINDOWS" /D "HAVE_FTIME" /D "HAVE_LIMITS_H" /D "HAVE_SYS_TIMEB_H" /D "HAVE_STRICMP" /D "HAVE_STRNICMP" /FD /c
+# ADD CPP /nologo /MD /W3 /GX /O2 /Ob2 /I "..\..\..\..\..\src" /D "NDEBUG" /D "PLATFORM_WIN32" /D "_CRTDBG_MAP_ALLOC" /D "XERCES_USE_FILEMGR_WINDOWS" /D "XERCES_USE_MUTEXMGR_WINDOWS" /D "XERCES_USE_ATOMICOPMGR_WINDOWS" /D "XERCES_USE_NETACCESSOR_WINSOCK" /D "XERCES_USE_WIN32_MSGLOADER" /D "XERCES_USE_TRANSCODER_WINDOWS" /D "XERCES_PATH_DELIMITER_BACKSLASH" /D "XERCES_BUILDING_LIBRARY" /D "WIN32" /D "_WINDOWS" /D "HAVE_FTIME" /D "HAVE_LIMITS_H" /D "HAVE_SYS_TIMEB_H" /D "HAVE_STRICMP" /D "HAVE_STRNICMP" /FD /c
 # SUBTRACT CPP /Fr
 # ADD BASE MTL /D "NDEBUG" /mktyplib203 /o "NUL" /win32
 # ADD MTL /D "NDEBUG" /mktyplib203 /o "NUL" /win32
@@ -71,7 +71,7 @@
 # PROP Ignore_Export_Lib 0
 # PROP Target_Dir ""
 # ADD BASE CPP /MTd /W3 /Gm /GX /Zi /Od /D "WIN32" /D "_DEBUG" /D "_WINDOWS" /YX /FD /c
-# ADD CPP /nologo /GB /MDd /W3 /Gm /GX /Zi /Od /I "..\..\..\..\..\src" /D "_DEBUG" /D "_CRTDBG_MAP_ALLOC" /D "XERCES_USE_FILEMGR_WINDOWS" /D "XERCES_USE_MUTEXMGR_WINDOWS" /D "XERCES_USE_ATOMICOPMGR_WINDOWS" /D "XERCES_USE_NETACCESSOR_WINSOCK" /D "XERCES_USE_WIN32_MSGLOADER" /D "XERCES_USE_TRANSCODER_WINDOWS" /D "XERCES_PATH_DELIMITER_BACKSLASH" /D "XERCES_BUILDING_LIBRARY" /D "WIN32" /D "_WINDOWS" /D "HAVE_FTIME" /D "HAVE_LIMITS_H" /D "HAVE_SYS_TIMEB_H" /D "HAVE_STRICMP" /D "HAVE_STRNICMP" /FD /c
+# ADD CPP /nologo /MDd /W3 /Gm /GX /Zi /Od /I "..\..\..\..\..\src" /D "_DEBUG" /D "_CRTDBG_MAP_ALLOC" /D "XERCES_USE_FILEMGR_WINDOWS" /D "XERCES_USE_MUTEXMGR_WINDOWS" /D "XERCES_USE_ATOMICOPMGR_WINDOWS" /D "XERCES_USE_NETACCESSOR_WINSOCK" /D "XERCES_USE_WIN32_MSGLOADER" /D "XERCES_USE_TRANSCODER_WINDOWS" /D "XERCES_PATH_DELIMITER_BACKSLASH" /D "XERCES_BUILDING_LIBRARY" /D "WIN32" /D "_WINDOWS" /D "HAVE_FTIME" /D "HAVE_LIMITS_H" /D "HAVE_SYS_TIMEB_H" /D "HAVE_STRICMP" /D "HAVE_STRNICMP" /FD /c
 # SUBTRACT CPP /Fr
 # ADD BASE MTL /D "_DEBUG" /mktyplib203 /o "NUL" /win32
 # ADD MTL /D "_DEBUG" /mktyplib203 /o "NUL" /win32
@@ -3184,10 +3184,6 @@
 # End Source File
 # Begin Source File
 
-SOURCE=..\..\..\..\..\src\xercesc\dom\DOMEntityResolver.hpp
-# End Source File
-# Begin Source File
-
 SOURCE=..\..\..\..\..\src\xercesc\dom\DOMError.hpp
 # End Source File
 # Begin Source File
@@ -3249,6 +3245,10 @@
 # Begin Source File
 
 SOURCE=..\..\..\..\..\src\xercesc\dom\DOMLSParserFilter.hpp
+# End Source File
+# Begin Source File
+
+SOURCE=..\..\..\..\..\src\xercesc\dom\DOMLSResourceResolver.hpp
 # End Source File
 # Begin Source File
 

Modified: xerces/c/trunk/Projects/Win32/VC7.1/xerces-all/XercesLib/XercesLib.vcproj
URL: http://svn.apache.org/viewcvs/xerces/c/trunk/Projects/Win32/VC7.1/xerces-all/XercesLib/XercesLib.vcproj?rev=355132&r1=355131&r2=355132&view=diff
==============================================================================
--- xerces/c/trunk/Projects/Win32/VC7.1/xerces-all/XercesLib/XercesLib.vcproj (original)
+++ xerces/c/trunk/Projects/Win32/VC7.1/xerces-all/XercesLib/XercesLib.vcproj Thu Dec  8 07:57:46 2005
@@ -2353,9 +2353,6 @@
 				RelativePath="..\..\..\..\..\src\xercesc\dom\DOMEntityReference.hpp">
 			</File>
 			<File
-				RelativePath="..\..\..\..\..\src\xercesc\dom\DOMEntityResolver.hpp">
-			</File>
-			<File
 				RelativePath="..\..\..\..\..\src\xercesc\dom\DOMError.hpp">
 			</File>
 			<File
@@ -2402,6 +2399,9 @@
 			</File>
 			<File
 				RelativePath="..\..\..\..\..\src\xercesc\dom\DOMLSParserFilter.hpp">
+			</File>
+			<File
+				RelativePath="..\..\..\..\..\src\xercesc\dom\DOMLSResourceResolver.hpp">
 			</File>
 			<File
 				RelativePath="..\..\..\..\..\src\xercesc\dom\DOMLSSerializer.hpp">

Modified: xerces/c/trunk/Projects/Win32/VC8/xerces-all/XercesLib/XercesLib.vcproj
URL: http://svn.apache.org/viewcvs/xerces/c/trunk/Projects/Win32/VC8/xerces-all/XercesLib/XercesLib.vcproj?rev=355132&r1=355131&r2=355132&view=diff
==============================================================================
--- xerces/c/trunk/Projects/Win32/VC8/xerces-all/XercesLib/XercesLib.vcproj (original)
+++ xerces/c/trunk/Projects/Win32/VC8/xerces-all/XercesLib/XercesLib.vcproj Thu Dec  8 07:57:46 2005
@@ -3138,10 +3138,6 @@
 				>
 			</File>
 			<File
-				RelativePath="..\..\..\..\..\src\xercesc\dom\DOMEntityResolver.hpp"
-				>
-			</File>
-			<File
 				RelativePath="..\..\..\..\..\src\xercesc\dom\DOMError.hpp"
 				>
 			</File>
@@ -3203,6 +3199,10 @@
 			</File>
 			<File
 				RelativePath="..\..\..\..\..\src\xercesc\dom\DOMLSParserFilter.hpp"
+				>
+			</File>
+			<File
+				RelativePath="..\..\..\..\..\src\xercesc\dom\DOMLSResourceResolver.hpp"
 				>
 			</File>
 			<File

Modified: xerces/c/trunk/src/Makefile.am
URL: http://svn.apache.org/viewcvs/xerces/c/trunk/src/Makefile.am?rev=355132&r1=355131&r2=355132&view=diff
==============================================================================
--- xerces/c/trunk/src/Makefile.am (original)
+++ xerces/c/trunk/src/Makefile.am Thu Dec  8 07:57:46 2005
@@ -266,7 +266,6 @@
 	xercesc/dom/DOMElement.hpp \
 	xercesc/dom/DOMEntity.hpp \
 	xercesc/dom/DOMEntityReference.hpp \
-	xercesc/dom/DOMEntityResolver.hpp \
 	xercesc/dom/DOMError.hpp \
 	xercesc/dom/DOMErrorHandler.hpp \
 	xercesc/dom/DOMException.hpp \
@@ -281,6 +280,7 @@
 	xercesc/dom/DOMLSOutput.hpp \
 	xercesc/dom/DOMLSParser.hpp \
 	xercesc/dom/DOMLSParserFilter.hpp \
+	xercesc/dom/DOMLSResourceResolver.hpp \
 	xercesc/dom/DOMLSSerializer.hpp \
 	xercesc/dom/DOMLSSerializerFilter.hpp \
 	xercesc/dom/DOMNamedNodeMap.hpp \

Modified: xerces/c/trunk/src/Makefile.in
URL: http://svn.apache.org/viewcvs/xerces/c/trunk/src/Makefile.in?rev=355132&r1=355131&r2=355132&view=diff
==============================================================================
--- xerces/c/trunk/src/Makefile.in (original)
+++ xerces/c/trunk/src/Makefile.in Thu Dec  8 07:57:46 2005
@@ -1120,7 +1120,6 @@
 	xercesc/dom/DOMElement.hpp \
 	xercesc/dom/DOMEntity.hpp \
 	xercesc/dom/DOMEntityReference.hpp \
-	xercesc/dom/DOMEntityResolver.hpp \
 	xercesc/dom/DOMError.hpp \
 	xercesc/dom/DOMErrorHandler.hpp \
 	xercesc/dom/DOMException.hpp \
@@ -1135,6 +1134,7 @@
 	xercesc/dom/DOMLSOutput.hpp \
 	xercesc/dom/DOMLSParser.hpp \
 	xercesc/dom/DOMLSParserFilter.hpp \
+	xercesc/dom/DOMLSResourceResolver.hpp \
 	xercesc/dom/DOMLSSerializer.hpp \
 	xercesc/dom/DOMLSSerializerFilter.hpp \
 	xercesc/dom/DOMNamedNodeMap.hpp \

Modified: xerces/c/trunk/src/xercesc/dom/DOM.hpp
URL: http://svn.apache.org/viewcvs/xerces/c/trunk/src/xercesc/dom/DOM.hpp?rev=355132&r1=355131&r2=355132&view=diff
==============================================================================
--- xerces/c/trunk/src/xercesc/dom/DOM.hpp (original)
+++ xerces/c/trunk/src/xercesc/dom/DOM.hpp Thu Dec  8 07:57:46 2005
@@ -57,7 +57,7 @@
 // Introduced in DOM Level 3
 #include <xercesc/dom/DOMLSParser.hpp>
 #include <xercesc/dom/DOMConfiguration.hpp>
-#include <xercesc/dom/DOMEntityResolver.hpp>
+#include <xercesc/dom/DOMLSResourceResolver.hpp>
 #include <xercesc/dom/DOMError.hpp>
 #include <xercesc/dom/DOMErrorHandler.hpp>
 #include <xercesc/dom/DOMImplementationLS.hpp>

Modified: xerces/c/trunk/src/xercesc/dom/DOMLSInput.hpp
URL: http://svn.apache.org/viewcvs/xerces/c/trunk/src/xercesc/dom/DOMLSInput.hpp?rev=355132&r1=355131&r2=355132&view=diff
==============================================================================
--- xerces/c/trunk/src/xercesc/dom/DOMLSInput.hpp (original)
+++ xerces/c/trunk/src/xercesc/dom/DOMLSInput.hpp Thu Dec  8 07:57:46 2005
@@ -40,7 +40,7 @@
   *
   * <p>There are two places that the application will deliver this input source
   * to the parser: as the argument to the parse method, or as the return value
-  * of the DOMEntityResolver.resolveEntity method.</p>
+  * of the DOMLSResourceResolver.resolveResource method.</p>
   *
   * <p>The DOMBuilder will use the DOMLSInput object to determine how to
   * read XML input. If there is a character stream available, the parser will
@@ -53,7 +53,7 @@
   * never modify it in any way (it may modify a copy if necessary).</p>
   *
   * @see DOMBuilder#parse
-  * @see DOMEntityResolver#resolveEntity
+  * @see DOMLSResourceResolver#resolveResource
   * @since DOM Level 3
   */
 class CDOM_EXPORT DOMLSInput

Modified: xerces/c/trunk/src/xercesc/dom/DOMLSOutput.hpp
URL: http://svn.apache.org/viewcvs/xerces/c/trunk/src/xercesc/dom/DOMLSOutput.hpp?rev=355132&r1=355131&r2=355132&view=diff
==============================================================================
--- xerces/c/trunk/src/xercesc/dom/DOMLSOutput.hpp (original)
+++ xerces/c/trunk/src/xercesc/dom/DOMLSOutput.hpp Thu Dec  8 07:57:46 2005
@@ -31,29 +31,11 @@
 
 
 /**
-  * This interface represents a single input source for an XML entity.
+  * This interface represents an output destination for data.
   *
-  * <p>This interface allows an application to encapsulate information about
-  * an input source in a single object, which may include a public identifier,
-  * a system identifier, a byte stream (possibly with a specified encoding),
-  * and/or a character stream.</p>
+  * Xerces currently doesn't use <code>DOMLSOutput</code> objects
   *
-  * <p>There are two places that the application will deliver this input source
-  * to the parser: as the argument to the parse method, or as the return value
-  * of the DOMEntityResolver.resolveEntity method.</p>
-  *
-  * <p>The DOMBuilder will use the DOMLSOutput object to determine how to
-  * read XML input. If there is a character stream available, the parser will
-  * read that stream directly; if not, the parser will use a byte stream, if
-  * available; if neither a character stream nor a byte stream is available,
-  * the parser will attempt to open a URI connection to the resource identified
-  * by the system identifier.</p>
-  *
-  * <p>A DOMLSOutput object belongs to the application: the parser shall
-  * never modify it in any way (it may modify a copy if necessary).</p>
-  *
-  * @see DOMBuilder#parse
-  * @see DOMEntityResolver#resolveEntity
+  * @see XMLFormatTarget
   * @since DOM Level 3
   */
 class CDOM_EXPORT DOMLSOutput
@@ -112,19 +94,6 @@
      */
     virtual const XMLCh* getEncoding() const = 0;
 
-
-    /**
-     * Get the public identifier for this input source.
-     *
-     * <p><b>"Experimental - subject to change"</b></p>
-     *
-     * @return The public identifier, or null if none was supplied.
-     * @see #setPublicId
-     * @since DOM Level 3
-     */
-    virtual const XMLCh* getPublicId() const = 0;
-
-
     /**
      * Get the system identifier for this input source.
      *
@@ -138,20 +107,6 @@
      */
     virtual const XMLCh* getSystemId() const = 0;
 
-
-    /**
-     * Get the base URI to be used for resolving relative URIs to absolute
-     * URIs. If the baseURI is itself a relative URI, the behavior is
-     * implementation dependent.
-     *
-     * <p><b>"Experimental - subject to change"</b></p>
-     *
-     * @return The base URI.
-     * @see #setBaseURI
-     * @since DOM Level 3
-     */
-    virtual const XMLCh* getBaseURI() const = 0;
-
     // -----------------------------------------------------------------------
     //  Setter methods
     // -----------------------------------------------------------------------
@@ -171,21 +126,6 @@
      */
     virtual void setEncoding(const XMLCh* const encodingStr) = 0;
 
-
-    /**
-     * Set the public identifier for this input source.
-     *
-     * <p>The public identifier is always optional: if the application writer
-     * includes one, it will be provided as part of the location information.</p>
-     *
-     * <p><b>"Experimental - subject to change"</b></p>
-     *
-     * @param publicId The public identifier as a string.
-     * @see #getPublicId
-     * @since DOM Level 3
-     */
-    virtual void setPublicId(const XMLCh* const publicId) = 0;
-
     /**
      * Set the system identifier for this input source.
      *
@@ -202,19 +142,6 @@
      * @since DOM Level 3
      */
     virtual void setSystemId(const XMLCh* const systemId) = 0;
-
-    /**
-     * Set the base URI to be used for resolving relative URIs to absolute
-     * URIs. If the baseURI is itself a relative URI, the behavior is
-     * implementation dependent.
-     *
-     * <p><b>"Experimental - subject to change"</b></p>
-     *
-     * @param baseURI The base URI.
-     * @see #getBaseURI
-     * @since DOM Level 3
-     */
-    virtual void setBaseURI(const XMLCh* const baseURI) = 0;
     //@}
 
     // -----------------------------------------------------------------------
@@ -236,32 +163,6 @@
      * @see BinInputStream
      */
     virtual BinInputStream* makeStream() const = 0;
-
-    /**
-     * Indicates if the parser should issue fatal error if this input source
-     * is not found.  If set to false, the parser issue warning message instead.
-     *
-     * <p><b>"Experimental - subject to change"</b></p>
-     *
-     * @param  flag True if the parser should issue fatal error if this input source is not found.
-     *               If set to false, the parser issue warning message instead.  (Default: true)
-     *
-     * @see #getIssueFatalErrorIfNotFound
-     */
-    virtual void setIssueFatalErrorIfNotFound(const bool flag) = 0;
-
-
-    /**
-     * Get the flag that indicates if the parser should issue fatal error if this input source
-     * is not found.
-     *
-     * <p><b>"Experimental - subject to change"</b></p>
-     *
-     * @return True if the parser should issue fatal error if this input source is not found.
-     *         False if the parser issue warning message instead.
-     * @see #setIssueFatalErrorIfNotFound
-     */
-    virtual bool getIssueFatalErrorIfNotFound() const = 0;
 
     /**
      * Called to indicate that this DOMLSOutput is no longer in use

Modified: xerces/c/trunk/src/xercesc/dom/DOMLSParser.hpp
URL: http://svn.apache.org/viewcvs/xerces/c/trunk/src/xercesc/dom/DOMLSParser.hpp?rev=355132&r1=355131&r2=355132&view=diff
==============================================================================
--- xerces/c/trunk/src/xercesc/dom/DOMLSParser.hpp (original)
+++ xerces/c/trunk/src/xercesc/dom/DOMLSParser.hpp Thu Dec  8 07:57:46 2005
@@ -30,7 +30,6 @@
 
 
 class DOMErrorHandler;
-class DOMEntityResolver;
 class DOMLSInput;
 class DOMLSParserFilter;
 class DOMNode;

Copied: xerces/c/trunk/src/xercesc/dom/DOMLSResourceResolver.hpp (from r354154, xerces/c/trunk/src/xercesc/dom/DOMEntityResolver.hpp)
URL: http://svn.apache.org/viewcvs/xerces/c/trunk/src/xercesc/dom/DOMLSResourceResolver.hpp?p2=xerces/c/trunk/src/xercesc/dom/DOMLSResourceResolver.hpp&p1=xerces/c/trunk/src/xercesc/dom/DOMEntityResolver.hpp&r1=354154&r2=355132&rev=355132&view=diff
==============================================================================
--- xerces/c/trunk/src/xercesc/parsers/DOMLSParserImpl.cpp (original)
+++ xerces/c/trunk/src/xercesc/parsers/DOMLSParserImpl.cpp Thu Dec  8 07:57:46 2005
@@ -30,7 +30,7 @@
 // ---------------------------------------------------------------------------
 #include <xercesc/parsers/DOMLSParserImpl.hpp>
 #include <xercesc/util/IOException.hpp>
-#include <xercesc/dom/DOMEntityResolver.hpp>
+#include <xercesc/dom/DOMLSResourceResolver.hpp>
 #include <xercesc/dom/DOMErrorHandler.hpp>
 #include <xercesc/dom/DOMLSParserFilter.hpp>
 #include <xercesc/dom/DOMNodeFilter.hpp>
@@ -168,7 +168,7 @@
 {
     if (XMLString::compareIStringASCII(name, XMLUni::fgDOMResourceResolver) == 0) 
     {
-        fEntityResolver = (DOMEntityResolver*)value;
+        fEntityResolver = (DOMLSResourceResolver*)value;
         if (fEntityResolver) {
             getScanner()->setEntityHandler(this);
             fXMLEntityResolver = 0;
@@ -802,7 +802,7 @@
     //
     if (fEntityResolver) {
 
-        DOMLSInput* is = fEntityResolver->resolveEntity(0, 0, publicId, systemId, baseURI);
+        DOMLSInput* is = fEntityResolver->resolveResource(0, 0, publicId, systemId, baseURI);
 
         if (is)
             return new (getMemoryManager()) Wrapper4DOMLSInput(is, true, getMemoryManager());
@@ -819,11 +819,11 @@
     //  return a null pointer to cause the default resolution.
     //
     if (fEntityResolver) {
-        DOMLSInput* is = fEntityResolver->resolveEntity(resourceIdentifier->getResourceIdentifierType()==XMLResourceIdentifier::ExternalEntity?XMLUni::fgDOMDTDType:XMLUni::fgDOMXMLSchemaType,
-                                                        resourceIdentifier->getNameSpace(),
-                                                        resourceIdentifier->getPublicId(),
-                                                        resourceIdentifier->getSystemId(), 
-                                                        resourceIdentifier->getBaseURI());
+        DOMLSInput* is = fEntityResolver->resolveResource(resourceIdentifier->getResourceIdentifierType()==XMLResourceIdentifier::ExternalEntity?XMLUni::fgDOMDTDType:XMLUni::fgDOMXMLSchemaType,
+                                                          resourceIdentifier->getNameSpace(),
+                                                          resourceIdentifier->getPublicId(),
+                                                          resourceIdentifier->getSystemId(), 
+                                                          resourceIdentifier->getBaseURI());
         if (is)
             return new (getMemoryManager()) Wrapper4DOMLSInput(is, true, getMemoryManager());    
     }

Modified: xerces/c/trunk/src/xercesc/parsers/DOMLSParserImpl.hpp
URL: http://svn.apache.org/viewcvs/xerces/c/trunk/src/xercesc/parsers/DOMLSParserImpl.hpp?rev=355132&r1=355131&r2=355132&view=diff
==============================================================================
--- xerces/c/trunk/src/xercesc/parsers/DOMLSParserImpl.hpp (original)
+++ xerces/c/trunk/src/xercesc/parsers/DOMLSParserImpl.hpp Thu Dec  8 07:57:46 2005
@@ -35,6 +35,7 @@
 class XMLEntityResolver;
 class XMLResourceIdentifier;
 class DOMStringListImpl;
+class DOMLSResourceResolver;
 
  /**
   * Introduced in DOM Level 3
@@ -519,7 +520,7 @@
       *         method or NULL otherwise to indicate no processing was done.
       *         The returned InputSource is owned by the DOMLSParser which is
       *         responsible to clean up the memory.
-      * @see DOMEntityResolver
+      * @see DOMLSResourceResolver
       * @see XMLEntityHandler
       */
     virtual InputSource* resolveEntity
@@ -645,7 +646,7 @@
     //-----------------------------------------------------------------------
     bool                        fAutoValidation;
     bool                        fValidation;
-    DOMEntityResolver*          fEntityResolver;
+    DOMLSResourceResolver*      fEntityResolver;
     XMLEntityResolver*          fXMLEntityResolver;
     DOMErrorHandler*            fErrorHandler;
     DOMLSParserFilter*          fFilter;

Modified: xerces/c/trunk/src/xercesc/parsers/XercesDOMParser.hpp
URL: http://svn.apache.org/viewcvs/xerces/c/trunk/src/xercesc/parsers/XercesDOMParser.hpp?rev=355132&r1=355131&r2=355132&view=diff
==============================================================================
--- xerces/c/trunk/src/xercesc/parsers/XercesDOMParser.hpp (original)
+++ xerces/c/trunk/src/xercesc/parsers/XercesDOMParser.hpp Thu Dec  8 07:57:46 2005
@@ -489,7 +489,7 @@
       *         method or NULL otherwise to indicate no processing was done.
       *         The returned InputSource is owned by the parser which is
       *         responsible to clean up the memory.
-      * @see DOMEntityResolver
+      * @see DOMLSResourceResolver
       * @see XMLEntityHandler
       */
     virtual InputSource* resolveEntity



---------------------------------------------------------------------
To unsubscribe, e-mail: commits-unsubscribe@xerces.apache.org
For additional commands, e-mail: commits-help@xerces.apache.org
--- xerces/c/trunk/src/xercesc/dom/DOMEntityResolver.hpp (original)
+++ xerces/c/trunk/src/xercesc/dom/DOMLSResourceResolver.hpp Thu Dec  8 07:57:46 2005
@@ -30,14 +30,14 @@
 class DOMLSInput;
 
 /**
   * DOMEntityResolver provides a way for applications to redirect references
   * to external entities.
   *
   * <p>Applications needing to implement customized handling for external
   * entities must implement this interface and register their implementation
-  * by setting the entityResolver attribute of the DOMBuilder.</p>
+  * by setting the entityResolver attribute of the DOMLSParser.</p>
   *
-  * <p>The DOMBuilder will then allow the application to intercept any
+  * <p>The DOMLSParser will then allow the application to intercept any
   * external entities (including the external DTD subset and external parameter
   * entities) before including them.</p>
   *
@@ -46,11 +46,11 @@
   * databases or other specialized input sources, or for applications that use
   * URNs.</p>
   *
-  * @see DOMBuilder#setEntityResolver
+  * @see DOMLSParser#getDomConfig
   * @see DOMLSInput#DOMLSInput
   * @since DOM Level 3
   */
-class CDOM_EXPORT DOMEntityResolver
+class CDOM_EXPORT DOMLSResourceResolver
 {
 protected:
     // -----------------------------------------------------------------------
@@ -58,7 +58,7 @@
     // -----------------------------------------------------------------------
     /** @name Hidden constructors */
     //@{    
-    DOMEntityResolver() {};
+    DOMLSResourceResolver() {};
     //@}
 
 private:
@@ -67,8 +67,8 @@
     // -----------------------------------------------------------------------
     /** @name Unimplemented constructors and operators */
     //@{
-    DOMEntityResolver(const DOMEntityResolver &);
-    DOMEntityResolver & operator = (const DOMEntityResolver &);
+    DOMLSResourceResolver(const DOMLSResourceResolver &);
+    DOMLSResourceResolver & operator = (const DOMLSResourceResolver &);
     //@}
 
 public:
@@ -81,52 +81,54 @@
      * Destructor
      *
      */
-    virtual ~DOMEntityResolver() {};
+    virtual ~DOMLSResourceResolver() {};
     //@}
 
     // -----------------------------------------------------------------------
     //  Virtual DOMEntityResolver interface
     // -----------------------------------------------------------------------
     /** @name Functions introduced in DOM Level 3 */
     //@{
     /**
-     * Allow the application to resolve external entities.
+     * Allow the application to resolve external resources.
      *
-     * <p>The DOMLSParser will call this method before opening any external
-     * entity except the top-level document entity (including the
-     * external DTD subset, external entities referenced within the
-     * DTD, and external entities referenced within the document
-     * element): the application may request that the DOMBuilder resolve
-     * the entity itself, that it use an alternative URI, or that it
-     * use an entirely different input source.</p>
-     *
-     * <p>Application writers can use this method to redirect external
-     * system identifiers to secure and/or local URIs, to look up
-     * public identifiers in a catalogue, or to read an entity from a
-     * database or other input source (including, for example, a dialog
-     * box).</p>
-     *
-     * <p>If the system identifier is a URL, the DOMBuilder parser must
-     * resolve it fully before reporting it to the application.</p>
-     *
-     * <p> The returned DOMLSInput is owned by the DOMBuilder which is
-     *     responsible to clean up the memory.
-     *
-     * @param publicId The public identifier of the external entity
-     *        being referenced, or null if none was supplied.
-     * @param systemId The system identifier of the external entity
-     *        being referenced.
-     * @param baseURI The absolute base URI of the resource being parsed, or
-     *        <code>null</code> if there is no base URI.
+     * The <code>DOMLSParser</code> will call this method before opening any external resource, 
+     * including the external DTD subset, external entities referenced within the DTD, and 
+     * external entities referenced within the document element (however, the top-level 
+     * document entity is not passed to this method). The application may then request that 
+     * the <code>DOMLSParser</code> resolve the external resource itself, that it use an 
+     * alternative URI, or that it use an entirely different input source.
+     *
+     * Application writers can use this method to redirect external system identifiers to 
+     * secure and/or local URI, to look up public identifiers in a catalogue, or to read 
+     * an entity from a database or other input source (including, for example, a dialog box).
+     *
+     * The returned DOMLSInput is owned by the DOMLSParser which is
+     * responsible to clean up the memory.
+     *
+     * @param resourceType The type of the resource being resolved. For XML [XML 1.0] resources 
+     *                     (i.e. entities), applications must use the value "http://www.w3.org/TR/REC-xml". 
+     *                     For XML Schema [XML Schema Part 1], applications must use the value 
+     *                     "http://www.w3.org/2001/XMLSchema". Other types of resources are outside 
+     *                     the scope of this specification and therefore should recommend an absolute 
+     *                     URI in order to use this method.
+     * @param namespaceUri The namespace of the resource being resolved, e.g. the target namespace 
+     *                     of the XML Schema [XML Schema Part 1] when resolving XML Schema resources.
+     * @param publicId     The public identifier of the external entity being referenced, or <code>null</code> 
+     *                     if no public identifier was supplied or if the resource is not an entity.
+     * @param systemId     The system identifier, a URI reference [IETF RFC 2396], of the external 
+     *                     resource being referenced, or <code>null</code> if no system identifier was supplied.
+     * @param baseURI      The absolute base URI of the resource being parsed, or <code>null</code> if 
+     *                     there is no base URI.
      * @return A DOMLSInput object describing the new input source,
      *         or <code>null</code> to request that the parser open a regular
      *         URI connection to the system identifier.
      *         The returned DOMLSInput is owned by the DOMBuilder which is
      *         responsible to clean up the memory.
      * @see DOMLSInput#DOMLSInput
      * @since DOM Level 3
      */
-    virtual DOMLSInput* resolveEntity
+    virtual DOMLSInput* resolveResource
     (
         const   XMLCh* const    resourceType
         , const XMLCh* const    namespaceUri
@@ -30,14 +30,14 @@
 
 /**
-  * DOMEntityResolver provides a way for applications to redirect references
+  * DOMLSResourceResolver provides a way for applications to redirect references
   * to external entities.
   *
@@ -81,52 +81,54 @@
 
     // -----------------------------------------------------------------------
-    //  Virtual DOMEntityResolver interface
+    //  Virtual DOMLSResourceResolver interface
     // -----------------------------------------------------------------------
     /** @name Functions introduced in DOM Level 3 */
@@ -81,52 +81,54 @@
      * @return A DOMLSInput object describing the new input source,
      *         or <code>null</code> to request that the parser open a regular
-     *         URI connection to the system identifier.
-     *         The returned DOMLSInput is owned by the DOMBuilder which is
+     *         URI connection to the resource.
+     *         The returned DOMLSInput is owned by the DOMLSParser which is
      *         responsible to clean up the memory.
      * @see DOMLSInput#DOMLSInput

Modified: xerces/c/trunk/src/xercesc/parsers/DOMLSParserImpl.cpp
URL: http://svn.apache.org/viewcvs/xerces/c/trunk/src/xercesc/parsers/DOMLSParserImpl.cpp?rev=355132&r1=355131&r2=355132&view=diff
==============================================================================